@@ -74,6 +74,7 @@ type Flags struct {
 type Style struct {
 	SelectedRow   ColorStyle        `yaml:"selected-row"`
 	ProgressModal ProgressModalOpts `yaml:"progress-modal"`
+	UseOldSizeBar bool              `yaml:"use-old-size-bar"`
 }
 
 // ProgressModalOpts defines options for progress modal
@@ -236,6 +237,11 @@ func (a *App) createUI() (UI, error) {
 				ui.SetCurrentItemNameMaxLen(a.Flags.Style.ProgressModal.CurrentItemNameMaxLen)
 			})
 		}
+		if a.Flags.Style.UseOldSizeBar {
+			opts = append(opts, func(ui *tui.UI) {
+				ui.UseOldSizeBar()
+			})
+		}
 		if a.Flags.Sorting.Order != "" || a.Flags.Sorting.By != "" {
 			opts = append(opts, func(ui *tui.UI) {
 				ui.SetDefaultSorting(a.Flags.Sorting.By, a.Flags.Sorting.Order)
