@@ -13,6 +13,9 @@ type TermApplication interface {
 	SetRoot(root tview.Primitive, fullscreen bool) *tview.Application
 	SetFocus(p tview.Primitive) *tview.Application
 	SetInputCapture(capture func(event *tcell.EventKey) *tcell.EventKey) *tview.Application
+	SetMouseCapture(
+		capture func(event *tcell.EventMouse, action tview.MouseAction) (*tcell.EventMouse, tview.MouseAction),
+	) *tview.Application
 	QueueUpdateDraw(f func()) *tview.Application
 	SetBeforeDrawFunc(func(screen tcell.Screen) bool) *tview.Application
 }
