@@ -2,8 +2,8 @@ package analyze
 
 import (
 	"encoding/json"
-	"fmt"
 	"io"
+	"strconv"
 )
 
 // EncodeJSON writes JSON representation of dir
@@ -24,7 +24,7 @@ func (f *Dir) EncodeJSON(writer io.Writer, topLevel bool) error {
 
 	if !f.GetMtime().IsZero() {
 		buff = append(buff, []byte(`,"mtime":`)...)
-		buff = append(buff, []byte(fmt.Sprint(f.GetMtime().Unix()))...)
+		buff = append(buff, []byte(strconv.FormatInt(f.GetMtime().Unix(), 10))...)
 	}
 
 	buff = append(buff, '}')
@@ -65,20 +65,23 @@ func (f *File) EncodeJSON(writer io.Writer, topLevel bool) error {
 	}
 	if f.GetSize() > 0 {
 		buff = append(buff, []byte(`,"asize":`)...)
-		buff = append(buff, []byte(fmt.Sprint(f.GetSize()))...)
+		buff = append(buff, []byte(strconv.FormatInt(f.GetSize(), 10))...)
 	}
 	if f.GetUsage() > 0 {
 		buff = append(buff, []byte(`,"dsize":`)...)
-		buff = append(buff, []byte(fmt.Sprint(f.GetUsage()))...)
+		buff = append(buff, []byte(strconv.FormatInt(f.GetUsage(), 10))...)
 	}
 	if !f.GetMtime().IsZero() {
 		buff = append(buff, []byte(`,"mtime":`)...)
-		buff = append(buff, []byte(fmt.Sprint(f.GetMtime().Unix()))...)
+		buff = append(buff, []byte(strconv.FormatInt(f.GetMtime().Unix(), 10))...)
 	}
 
 	if f.Flag == '@' {
 		buff = append(buff, []byte(`,"notreg":true`)...)
 	}
+	if f.Flag == 'H' {
+		buff = append(buff, []byte(`,"ino":`+strconv.FormatUint(f.Mli, 10)+`,"hlnkc":true`)...)
+	}
 
 	buff = append(buff, '}')
 
