@@ -18,7 +18,7 @@ func TestShowDevicesWithError(t *testing.T) {
 
 	getter := device.LinuxDevicesInfoGetter{MountsPath: "/xyzxyz"}
 
-	ui := CreateUI(app, simScreen, &bytes.Buffer{}, false, false, false)
+	ui := CreateUI(app, simScreen, &bytes.Buffer{}, false, false, false, false, false)
 	err := ui.ListDevices(getter)
 
 	assert.Contains(t, err.Error(), "no such file")
