@@ -5,6 +5,7 @@ package tui
 
 import (
 	"os"
+	"syscall"
 )
 
 func getShellBin() string {
@@ -31,3 +32,7 @@ func (ui *UI) spawnShell() {
 		}
 	})
 }
+
+func stopProcess() error {
+	return syscall.Kill(syscall.Getpid(), syscall.SIGTSTP)
+}
