@@ -5,9 +5,14 @@ import (
 
 	"github.com/dundee/gdu/v5/pkg/fs"
 	"github.com/gdamore/tcell/v2"
+	"github.com/rivo/tview"
 )
 
 func (ui *UI) keyPressed(key *tcell.EventKey) *tcell.EventKey {
+	if ui.handleCtrlZ(key) == nil {
+		return nil
+	}
+
 	if ui.pages.HasPage("file") {
 		return key // send event to primitive
 	}
@@ -107,6 +112,25 @@ func (ui *UI) handleInfoPageEvents(key *tcell.EventKey) *tcell.EventKey {
 	return key
 }
 
+// handle ctrl+z job control
+func (ui *UI) handleCtrlZ(key *tcell.EventKey) *tcell.EventKey {
+	if key.Key() == tcell.KeyCtrlZ {
+		ui.app.Suspend(func() {
+			termApp := ui.app.(*tview.Application)
+			termApp.Lock()
+			defer termApp.Unlock()
+
+			err := stopProcess()
+			if err != nil {
+				ui.showErr("Error sending STOP signal", err)
+			}
+		})
+		return nil
+	}
+
+	return key
+}
+
 func (ui *UI) handleQuit(key *tcell.EventKey) *tcell.EventKey {
 	switch key.Rune() {
 	case 'Q':
