@@ -4,6 +4,7 @@ import (
 	"time"
 
 	"github.com/dundee/gdu/v5/internal/common"
+	"github.com/dundee/gdu/v5/pkg/path"
 )
 
 func (ui *UI) updateProgress() {
@@ -16,6 +17,7 @@ func (ui *UI) updateProgress() {
 	doneChan := ui.Analyzer.GetDone()
 
 	var progress common.CurrentProgress
+	start := time.Now()
 
 	for {
 		select {
@@ -25,15 +27,20 @@ func (ui *UI) updateProgress() {
 		}
 
 		func(itemCount int, totalSize int64, currentItem string) {
+			delta := time.Since(start).Round(time.Second)
+
 			ui.app.QueueUpdateDraw(func() {
 				ui.progress.SetText("Total items: " +
 					color +
 					common.FormatNumber(int64(itemCount)) +
-					"[white:black:-] size: " +
+					"[white:black:-], size: " +
 					color +
 					ui.formatSize(totalSize, false, false) +
+					"[white:black:-], elapsed time: " +
+					color +
+					delta.String() +
 					"[white:black:-]\nCurrent item: [white:black:b]" +
-					currentItem)
+					path.ShortenPath(currentItem, ui.currentItemNameMaxLen))
 			})
 		}(progress.ItemCount, progress.TotalSize, progress.CurrentItemName)
 
