@@ -50,6 +50,7 @@ type UI struct {
 	selectedTextColor       tcell.Color
 	selectedBackgroundColor tcell.Color
 	currentItemNameMaxLen   int
+	useOldSizeBar           bool
 	defaultSortBy           string
 	defaultSortOrder        string
 	markedRows              map[int]struct{}
@@ -180,6 +181,11 @@ func (ui *UI) SetCurrentItemNameMaxLen(len int) {
 	ui.currentItemNameMaxLen = len
 }
 
+// UseOldSizeBar uses the old size bar (# chars) instead of the new one (unicode block elements)
+func (ui *UI) UseOldSizeBar() {
+	ui.useOldSizeBar = true
+}
+
 // SetChangeCwdFn sets function that can be used to change current working dir
 // during dir browsing
 func (ui *UI) SetChangeCwdFn(fn func(string) error) {
